//*----------------------------------------------------------------------------
//*         ATMEL Microcontroller Software Support  -  ROUSSET  -
//*----------------------------------------------------------------------------
//* The software is delivered "AS IS" without warranty or condition of any
//* kind, either express, implied or statutory. This includes without
//* limitation any warranty or condition with respect to merchantability or
//* fitness for any particular purpose, or against the infringements of
//* intellectual property rights of others.
//*----------------------------------------------------------------------------
//* File Name           : spi_master.c
//* Object              : SPI master application written in C
//* 1.0 24/01/06 SYO	: Creation
//*----------------------------------------------------------------------------

// Include Standard files
#include "Board.h"

// #define  GLOBAL
#include "global.h"
#include "common.h"
#include "handler.h"
#include "spi_master.h"
#include "spi_main.h"


unsigned char Spi_Master (void)
{
	unsigned char error;
        unsigned long lesewert;
	AT91PS_SPI     pSPI = AT91C_BASE_SPI;
	
	error = 0;

	AT91F_SPI_Open ();	

        pSPI -> SPI_IER =  	(AT91C_SPI_RDRF + AT91C_SPI_TDRE + AT91C_SPI_MODF + AT91C_SPI_OVRES+ 
					 AT91C_SPI_NSSR + AT91C_SPI_TXEMPTY + AT91C_SPI_SPIENS);

	// Cfg SPI MR
		// SPI is in master mode + CS not variable + CS directly connected + no Fault mode + min DLYBCS
		pSPI -> SPI_MR = (AT91C_SPI_MSTR + AT91C_SPI_MODFDIS);
	
	// Cfg CSR0 = 
		// SPCK active high + Data sampled on the falling edge of SPCK + 
		// CS inactive at the end of the transfer + cpt_bits to send + min baud rate + dlybct
		AT91F_Set_SPI_CSR (AT91C_BASE_SPI, (0 +  0 + 0 + AT91C_SPI_BITS_8 + 0x0000FF08), CSR0); //Baudrate MCK/256 -->FF , CSAAT fr CS an	
	
	/*//schreiben fr 16bits-Mode
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x0200);//Schreibbefehl fr EEPROM-Adresse 0000
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x5500);//Schreiben den Wert 0x55 auf EEPROM-Adresse 0000
        while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
        
	//lesen fr 16bits-Mode
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x0300);//Lesebefehl fr EEPROM-Adresse 0000
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x0000);//Dummiefolge
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       lesewert=AT91F_SPI_Read_Data (AT91C_BASE_SPI);  */
	
                
        //schreiben fr 8bits-Mode
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x00000006);//WREN
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x00000002);//Schreibbefehl fr EEPROM
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x00000000);// EEPROM-Adresse 0000
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x00000055);// 0x55 schreiben
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x01000004);//WRDI und CS-Disable
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
        
	//lesen fr 8bits-Mode
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x00000003);//Lesebefehl fr EEPROM
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x00000000);//EEPROM-Adresse 0000
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x010000FF);//Bummybits frs Lesen und CS-Disable
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       lesewert=AT91F_SPI_Read_Data (AT91C_BASE_SPI); // */ 
                
	/*AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x0108);//Status Register schreiben
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist
       
       AT91F_SPI_Send_Data (AT91C_BASE_SPI, 0x05FF);//lesen
       while (spi_Tdre_Flag == 0);//warten bis TDR leer ist */
       
       lesewert=AT91F_SPI_Read_Data (AT91C_BASE_SPI);// fs Angucken beim Debuggen
       
       
       
	// Issu a last transfer command in order to make the NPCS0 signal rise
	pSPI -> SPI_CR = AT91C_SPI_LASTXFER;

        return error;
}
